@@ -17,6 +17,7 @@ class InheritDeprecated(LineCheck):
 		"bash-completion": "bash-completion-r1",
 		"boost-utils": False,
 		"clutter": "gnome2",
+		"cmake-utils": "cmake",
 		"confutils": False,
 		"distutils": "distutils-r1",
 		"epatch": "(eapply since EAPI 6)",
@@ -32,6 +33,7 @@ class InheritDeprecated(LineCheck):
 		"gst-plugins10": "gstreamer",
 		"ltprune": False,
 		"mono": "mono-env",
+		"netsurf": False,
 		"python": "python-r1 / python-single-r1 / python-any-r1",
 		"ruby": "ruby-ng",
 		"user": "GLEP 81",
